#
# spec file for package pcsc-acsccid
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 Advanced Card Systems Ltd.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1140
%if %( pkg-config --modversion udev ) > 190
%define _udevrulesdir /usr/lib/udev/rules.d
%else
%define _udevrulesdir /lib/udev/rules.d
%endif
%endif

%if 0%{?sles_version} == 11
%define libusb_ver 1.0.8
%define pcsc_lite_ver 1.4.102
%else
%define libusb_ver 1.0.9
%define pcsc_lite_ver 1.8.3
%endif

Name:           pcsc-acsccid
%define _name acsccid
BuildRequires:  flex
BuildRequires:  libusb-1_0-devel >= %{libusb_ver}
BuildRequires:  pcsc-lite-devel >= %{pcsc_lite_ver}
BuildRequires:  pkg-config
%if 0%{?suse_version} >= 1140
BuildRequires:  pkgconfig(udev)
%endif
Version:        1.1.11
Release:        2.2
URL:            http://acsccid.sourceforge.net/
Summary:        PCSC Driver for ACS CCID Based Smart Card Readers
License:        LGPL-2.1-or-later
Group:          Productivity/Security
Source:         http://downloads.sourceforge.net/%{_name}/%{_name}-%{version}.tar.bz2
Source1:        %{name}-rpmlintrc
%if 0%{?sles_version} == 11
# PATCH-FIX-SLE acsccid-1.1.10-libhal.patch godfrey.chung@acs.com.hk -- Fix the compatibility with libhal.
Patch0:         %{_name}-1.1.10-libhal.patch
# PATCH-FIX-SLE acsccid-1.1.11-polling-thread.patch godfrey.chung@acs.com.hk -- Add polling thread support for slot status.
Patch1:         %{_name}-1.1.11-polling-thread.patch
# PATCH-FIX-SLE acsccid-1.1.11-polling-unplug.patch godfrey.chung@acs.com.hk -- Let pcsc-lite delay the polling if the reader is unplugged.
Patch2:         %{_name}-1.1.11-polling-unplug.patch
# PATCH-FIX-SLE acsccid-1.1.10-libusb-1.0.8.patch godfrey.chung@acs.com.hk -- Fix the compatibility with libusb 1.0.8.
Patch3:         %{_name}-1.1.10-libusb-1.0.8.patch
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       pcsc-lite >= %{pcsc_lite_ver}
%define ifddir %(pkg-config libpcsclite --variable=usbdropdir)

Enhances:       modalias(usb:v072FpB301d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB304d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB305d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp8300d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp8302d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp8307d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp8301d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp90CCd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp90D8d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB100d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB500d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB101d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB102d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB103d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB10Cd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB104d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB113d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB114d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB116d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB117d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB000d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB501d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB504d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB506d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB505d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp90D2d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp8306d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2011d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp8900d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp8901d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp8902d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp1205d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp1204d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp1206d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2200d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2214d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp1280d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2207d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp222Bd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2206d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp222Ed*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2237d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2219d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2203d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp221Ad*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2229d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp222Dd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2218d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp221Bd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2232d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2242d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2238d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp225Fd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp224Fd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp223Bd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp223Ed*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp223Dd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2244d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2259d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp225Bd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp225Cd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp226Bd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp226Ad*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp223Fd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2239d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2211d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2252d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2100d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2224d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp220Fd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2217d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2223d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2208d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp0901d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp220Ad*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2215d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2220d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2233d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2234d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2235d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2236d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2213d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp222Cd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp220Cd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2258d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2303d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2308d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2302d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2307d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2306d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp230Ad*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2309d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2301d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp2300d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp0102d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp0103d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp0100d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp224Ad*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp8201d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp8206d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp8207d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp8202d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp8205d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp90DBd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB200d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB106d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072FpB112d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp9000d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp90CFd*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp0101d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp9006d*dc*dsc*dp*ic*isc*ip*)
Enhances:       modalias(usb:v072Fp90CEd*dc*dsc*dp*ic*isc*ip*)

%description
This package contains a ACS USB CCID (Chip/Smart Card Interface
Devices) driver.

This driver is meant to be used with the PCSC-Lite daemon from the
pcsc-lite package.

%prep
%setup -q -n %{_name}-%{version}
%if 0%{?sles_version} == 11
%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%endif
cp -a src/openct/LICENSE LICENSE.openct
cp -a src/towitoko/README README.towitoko

%build
%if 0%{?sles_version} == 11
%configure \
    PCSC_CFLAGS="-I%{_builddir}/%{_name}-%{version}/MacOSX" \
    PCSC_LIBS="%(pkg-config --libs libpcsclite 2>/dev/null)" \
    --enable-composite-as-multislot
%else
%configure
%endif
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}
%if 0%{?suse_version} >= 1140
mkdir -p %{buildroot}/%{_udevrulesdir}
sed 's:GROUP="pcscd":GROUP="scard":' <src/92_pcscd_acsccid.rules >%{buildroot}/%{_udevrulesdir}/92_pcscd_acsccid.rules
%endif

%files
%defattr(-,root,root)
%if 0%{?suse_version} < 1500
%doc AUTHORS ChangeLog COPYING LICENSE.openct README README.towitoko
%else
%doc AUTHORS ChangeLog README README.towitoko
%license COPYING LICENSE.openct
%endif
%{ifddir}/*
%if 0%{?suse_version} >= 1140
%{_udevrulesdir}/*.rules
%endif

%changelog
* Mon Jun 10 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N syntax instead of deprecated %%patchN.
* Wed Mar 27 2024 Godfrey Chung <godfrey.chung@acs.com.hk>
- Updated to version 1.1.11.
  * Add the following readers support:
    WalletMate II 1S CL Reader
    WalletMate II V2 Upgrade
    ACR1555 1S CL Reader
    ACR1555 USB FW_Upgrade
  * Enable WalletMate II (composite device) as multi-slot reader.
  * Enable the 2nd interface of WalletMate II as SAM slot.
  * Enable ACR1555U (composite device) as multi-slot reader.
  * Enable the 2nd interface of ACR1555U as SAM slot.
- Replaced acsccid-1.1.10-polling-thread.patch with
  acsccid-1.1.11-polling-thread.patch.
- Replaced acsccid-1.1.10-polling-unplug.patch with
  acsccid-1.1.11-polling-unplug.patch.
* Fri Aug  4 2023 Godfrey Chung <godfrey.chung@acs.com.hk>
- Updated to version 1.1.10.
  * Add the following readers support:
    ACR40U ICC Reader
    SCR FW_Upgrade
    ACR1552 1S CL Reader
    ACR1552 CL Reader
    ACR1552 USB FW_Upgrade
  * Enable ACR1552U-M1 (composite device) as multi-slot reader.
  * Enable the 2nd interface of ACR1552U-M1 as SAM slot.
  * Fix missing initialization in get_end_points().
  * Update _usbDevice.has_interrupt in get_end_points().
  * Initialize multislot for interrupt endpoint only in OpenUSBByName().
  * Simplify the code for delaying the write operation.
  * Allow ACR38 or the reader which needs write delay in WriteUSB().
  * Check the packet size to avoid infinite loop in WriteUSB().
  * Use #pragma pack(1) for all platforms in src/ifdhandler.c.
- Replaced acsccid-1.1.9-libhal.patch with acsccid-1.1.10-libhal.patch.
- Replaced acsccid-1.1.9-polling-thread.patch with
  acsccid-1.1.10-polling-thread.patch.
- Replaced acsccid-1.1.9-polling-unplug.patch with
  acsccid-1.1.10-polling-unplug.patch.
- Replaced acsccid-1.1.9-libusb-1.0.8.patch with
  acsccid-1.1.10-libusb-1.0.8.patch.
* Fri Mar 24 2023 Godfrey Chung <godfrey.chung@acs.com.hk>
- Updated to version 1.1.9.
  * Add the following readers support:
    APG8201-B2RO
    ACR39U-W1 Top Reader
    ACR39U-W1 Edge Reader
    WalletMate 1S CL Reader
    WalletMate USB FW_Upgrade
    ACR1581 1S Dual Reader
    ACR1581 USB FW_Upgrade
    ACR40T ICC Reader
    ACR40 FW_Upgrade
    ACR39 FW_Upgrade
  * Fix misleading read length in CCID_Receive().
  * Fix ACR1281U-C1 communication issue with NXP SAM AV3.
- Replaced acsccid-1.1.5-libhal.patch with acsccid-1.1.9-libhal.patch.
- Replaced acsccid-1.1.5-polling-thread.patch with
  acsccid-1.1.9-polling-thread.patch.
- Replaced acsccid-1.1.6-polling-unplug.patch with
  acsccid-1.1.9-polling-unplug.patch.
- Replaced acsccid-1.1.5-libusb-1.0.8.patch with
  acsccid-1.1.9-libusb-1.0.8.patch.
- Enabled paralled make.
- Replaced makeinstall macro with the expanded version.
- Removed clean section.
- Marked license files.
- Replaced RPM_BUILD_ROOT with buildroot.
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut through the -mini flavors.
* Wed Jan  8 2020 Godfrey Chung <godfrey.chung@acs.com.hk>
- Updated to version 1.1.8.
  * Add the following readers support:
    ACR39U-W1 Top ICC Reader
    ACR39U-W1 Edge ICC Reader
    ACR1251T CL Reader
  * Remove response timeout fix for APG8201 and APG8201Z.
* Thu Jul 25 2019 Godfrey Chung <godfrey.chung@acs.com.hk>
- Updated to version 1.1.7.
  * Add the following readers support:
    ACR3201 ICC Reader
    CryptoMate EVO
  * Fix APG8201 response timeout issue.
  * Do not build simclist with (unused) file dump option.
* Wed Jan  2 2019 godfrey.chung@acs.com.hk
- Added missing devices to Enhances:.
  * ACM1252U-Z2ACE    (VID: 072F, PID: 225B)
  * ACM1252U-Z2ACE BL (VID: 072F, PID: 225C)
* Tue Oct 30 2018 godfrey.chung@acs.com.hk
- Updated to version 1.1.6.
  * Add the following readers support:
    ACR1252 CL Reader           (ACM1252U-Z2ACE)
    ACR1252 USB FW_Upgrade v100 (ACM1252U-Z2ACE BL)
  * Enable TLV properties for APG8201-B2 in IFDHControl().
  * Enable TLV properties for APG8201-B2 in process_spe_ppdu().
  * Fix ACR39U T=0 APDU problem in CmdXfrBlockTPDU_T0().
  * Return 6B 80 for supported readers in CCID_Receive().
  * Remove extra_egt() causing problems.
  * Fix undefined symbol yylex.
  * Set the status to absent if SAM reset failed in IFDHPowerICC().
  * Fix libusb config descriptor leak.
  * Fix leaking an allocated bundle in case no matching reader was found.
  * Enable ICC extended APDU for ACR1281U-C1 >= v526.
  * Add IOCTL_SMARTCARD_TOGGLE_CARD_STATE for SAM slot.
- Replaced acsccid-1.1.5-polling-unplug.patch with
  acsccid-1.1.6-polling-unplug.patch.
* Wed Sep 12 2018 godfrey.chung@acs.com.hk
- Backported to SLE 11.
  * Set libusb version to 1.0.8.
  * Set pcsc-lite version to 1.4.102.
  * Added acsccid-1.1.5-libhal.patch: Fix the compatibility with libhal.
  * Added acsccid-1.1.5-polling-thread.patch: Add polling thread support for
    slot status.
  * Added acsccid-1.1.5-polling-unplug.patch: Let pcsc-lite delay the polling if
    the reader is unplugged.
  * Added acsccid-1.1.5-libusb-1.0.8.patch: Fix the compatibility with libusb
    1.0.8.
* Wed Oct 25 2017 godfrey.chung@acs.com.hk
- Updated to version 1.1.5.
  * Add the following readers support:
    ACR1252IMP 1S CL Reader
    AMR220 Reader
    APG8201-B2
  * Fix ACR39U memory card problem.
  * Rename ACR3901U ICC Reader to ACR3901 ICC Reader.
  * PowerOn: use automatic voltage selection when needed.
  * PowerOn: move from 1.8V to 5V if 1.8V is not supported.
  * PowerOn: always try every possible voltage values.
  * udev rule: allow rule overwrite.
* Fri Dec 16 2016 godfrey.chung@acs.com.hk
- Updated to version 1.1.4.
* Thu Jun 23 2016 godfrey.chung@acs.com.hk
- Updated to version 1.1.3.
* Fri Feb 19 2016 godfrey.chung@acs.com.hk
- Updated to version 1.1.2.
* Fri Nov  6 2015 godfrey.chung@acs.com.hk
- Updated to version 1.1.1.
* Mon Dec 15 2014 godfrey.chung@acs.com.hk
- Updated to version 1.1.0.
* Thu Jul  3 2014 godfrey.chung@acs.com.hk
- Updated to version 1.0.8.
* Tue Jun 17 2014 godfrey.chung@acs.com.hk
- Updated to version 1.0.7.
* Wed Apr 23 2014 godfrey.chung@acs.com.hk
- Updated to version 1.0.6.
* Thu Sep  5 2013 godfrey.chung@acs.com.hk
- Updated to version 1.0.5.
* Thu Oct 18 2012 fcrozat@suse.com
- Fix build with new udev rules.d directory location.
* Mon Jun 25 2012 godfrey.chung@acs.com.hk
- Updated to version 1.0.4.
* Fri Jan 13 2012 godfrey.chung@acs.com.hk
- Updated to version 1.0.3.
- Updated copyright.
- Added USB IDs of readers.
- Removed acsccid-1.0.2-pcscd-autostart.patch.
- Removed pcsc-lite-1_7_3.patch.
- Included ChangeLog from upstream.
* Wed Jun 22 2011 wr@rosenauer.org
- fix compatibility with pcsc-lite >= 1.7.3
* Wed Jun 22 2011 godfrey.chung@acs.com.hk
- Updated to version 1.0.2 (22/6/2011):
  * Fix non-redistributable reference manual problem.
- Updated Url and Source.
* Fri Apr 29 2011 godfrey.chung@acs.com.hk
- Created package.
- Based on pcsc-ccid.spec.
